// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
// -*-C++-*-
//
// File:      OmImageDisplay.h
// Author:    Jorgo Bakker (jbakker@astro.estec.esa.nl)
// Generated: Fri Sep  6 12:09:43 MEST 2002
// Usage:     -
// Info:      -

#ifndef OmImageDisplay_h
#define OmImageDisplay_h

#include "Ds9.h"
#include "OmSourceParameters.h"
#include <vector>
#include <cstdio>
#include "OmSourceTempFile.h"
#include <iostream>
#include <cstring>
class OmSourceRegions;
class OmImageDisplay : public Ds9
{
public:
  OmImageDisplay() 
  {
       if (strlen(_regionFile) < 2) TempFile::createTempFile(_regionFile);};
  ~OmImageDisplay() {remove(_regionFile); };
  void toRegion(const OmSourceParameters&,  const char* colour = "green", const bool deleteRegions = true);
  void toRegion1(const OmSourceParameters&,  const char *colour = "green", const bool deleteRegions = true);


  void displayCurrentSourceList( const char* colour = "green", const bool erase = true);
  void displayCurrentSourceList1( const char* colour = "green", const bool erase = true);

 
 

  void displayBackgroundRegions(const OmSourceParameters&);
  void displayBackgroundRegions(const OmSourceRegions *, const float radius);
  void displaySourceRegions(const OmSourceParameters&);
  void displaySourceRegions(const OmSourceRegions *, const float radius);
  void displayBackgroundRegions(const vector<OmSourceParameter> & sources, const char* colour="blue");



  void displaySourceRegions(const OmSourceRegions *, const vector<float>& radius, const char* colour);


  void deleteRegions(const OmSourceRegions* sources);

  void setNewRegionsColour ( string colour) 
  {

     send( string("regions color ") + colour );

  }  


  void zoomTo(const OmSourceParameter&, int zoomFactor = 15, const char* colour1="blue", const char* colour2 = "cyan");
  void zoom1To(const OmSourceParameter&, int zoomFactor = 15, const char* colour1="blue");


  void displaySource(const int no, const OmSourceParameter&);

  void plotPoint(const OmSourceParameter& s);

protected:
  // only derived classes can use these

private:
  // member functions
  OmImageDisplay(const OmImageDisplay&);
 
  OmImageDisplay& operator=(const OmImageDisplay&);
  static char _regionFile[100];
  // member data
  /*
    ???BUG: cannot use any member on xmmps03???
    int xMax;
   */
};



#endif



