// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
#ifndef OmSourceBackgroundDlg_h
#define OmSourceBackgroundDlg_h
#include <qapplication.h>

#include <qdialog.h>
#include <qstring.h>

#include "OmSourceVersionNo.h"
#include <vector>



class OmSourceButton;
class QTable;
class OmImageDisplay;
class QTimer;
class OmSourceParameter;
class OmSourceLabel;
class QSpinBox;
class Average;
class PhotometryDlg;
class OmSpinBox;


class BackgroundDlg : public QDialog
{
    Q_OBJECT
     
 private slots:
    void deleteList();    
    //    void mousePressEvent( QMouseEvent *e );
    void updateRegions(); 
    void apertureRadiusHasChanged(int radius);
    void updateTimeChanged( int time );
    void backgroundRegionColourChanged( int no );
signals:
    void updateDisplay();     

public:
    BackgroundDlg( QWidget *parent,  
           OmImageDisplay *imageDispaly,  OmSourceParameter* source, int zoomFactor);
    ~BackgroundDlg();
    float getBackgroundMode() const {return _backgroundMode; };
 private:

    void updateTable(float x, float y, float radius, float counts);
    void update();

    OmImageDisplay *_imageDisplay;
    OmSourceParameter* _source;
    int _zoomFactor;
    OmSourceButton* _deleteListBtn;    
    OmSourceLabel *_label;
    QTable *_table;
    QTimer *_timer;
    //    int _noBackgroundSources; 
    float _apertureRadius; 

    OmSourceLabel* _apertureTxt;
    QSpinBox* _apertureSpinBox;
    OmSourceLabel* _averageTxt;    

    OmSpinBox*  _spinBoxColour;
    QSpinBox*  _spinBoxUpdate;


    float _backgroundMode;
    Average* _average;
    int _time; 
    float _nx, _ny;  
    //    QDialog* _photometryDlg;
    //    PhotometryDlg* _photometryDlg;

public:
    static vector<OmSourceParameter> _backgroundList;


};

#endif



