// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.

#ifndef ALLOCATE_H
#define ALLOCATE_H


/***********************************************************************
*                                                                              *
* allocate -- allocates memory for a double array of any type                  *
*                                                                              *
* Parameters -- array - pointer to the array                                   *
*               nrows - number of rows in the array                            *
*               ncolumns - number of columns in the array                      *
********************************************************************************/
template <class kind, class kind1, class kind2>
void allocate(kind ***array, kind1 nrows, kind2 ncolumns)
{
    *array = new kind*[nrows];
  
    for (int j = 0; j < nrows; j++)
        (*array)[j] = new kind[ncolumns];


}


/*******************************************************************************
*                                                                              *
* de_allocate -- de-allocates memory for a double array of any type            *
*                                                                              *
* Parameters -- array - pointer to the array                                   *
*               nrows - number of rows in the array                            *
*               ncolumns - number of columns in the array                      *
********************************************************************************/
template<class kind, class type>
void de_allocate(kind ***array, type nrows)
{
    if (*array == NULL) return;

    for (int i = 0; i < nrows; i++)
    {
        if ((*array)[i]) delete [] (*array)[i];
    }
    delete [] *array;


    *array = NULL;

}
#endif
